@@ -68,8 +68,11 @@ class HyperSklearn:
             X_train, y_train = get_Xy_from_df(fun_control["train"], fun_control["target_column"])
             X_test, y_test = get_Xy_from_df(fun_control["test"], fun_control["target_column"])
             model.fit(X_train, y_train)
-            df_preds = model.predict(X_test)
-            df_eval = fun_control["metric_sklearn"](y_test, df_preds)
+            if fun_control["predict_proba"]:
+                df_preds = model.predict_proba(X_test)
+            else:
+                df_preds = model.predict(X_test)
+            df_eval = fun_control["metric_sklearn"](y_test, df_preds, **fun_control["metric_params"])
         except Exception as err:
             print(f"Error in fun_sklearn(). Call to evaluate_model failed. {err=}, {type(err)=}")
             df_eval = np.nan
