@@ -25,5 +25,7 @@ def fun_control_init():
         "eval": None,
         "k_folds": None,
         "device": None,
+        "metric_params": {},
+        "show_batch_interval": 1_000_000,
     }
     return fun_control
